@@ -7,8 +7,8 @@
 #'     analogous function with a similar -- more style consistent -- name. See
 #'     also the \code{NEWS} file.
 #' 
-#' Deprecated functions still work as expected, but they print out a warning
-#' suggesting to use the new function (name).
+#' As of v0.6.8-1 deprecated functions will throw errors (`stop()`) and print out the suggested
+#' new function (name).
 #' 
 #' @name deprecated-functions
 #' @param ... arguments passed to deprecated functions.
@@ -20,7 +20,7 @@ NULL
 #' @export
 beta_names <- function(...) {
   
-  warning("DEPRECATED: Please use get_beta_names() instead of beta_names().")
+  stop("DEPRECATED: Please use get_beta_names() instead of beta_names().")
   get_beta_names(...)
 }
 
@@ -28,7 +28,7 @@ beta_names <- function(...) {
 #' @rdname deprecated-functions
 #' @export
 bounds_theta <- function(...) {
-  warning("DEPRECATED: Please use get_theta_bounds() instead of bounds_theta().")
+  stop("DEPRECATED: Please use get_theta_bounds() instead of bounds_theta().")
   get_theta_bounds(...)
 }
 
@@ -36,7 +36,7 @@ bounds_theta <- function(...) {
 #' @param z,W.z see \code{\link{deriv_W}}
 #' @export
 d1W_1 <- function(z, W.z = W(z, branch = -1)) {
-  warning("DEPRECATED: Please usee deriv_W(z, branch = -1) instead of d1W_1(z).")
+  stop("DEPRECATED: Please usee deriv_W(z, branch = -1) instead of d1W_1(z).")
   deriv_W(z, branch = -1, W.z = W.z)
 }
 
@@ -44,21 +44,21 @@ d1W_1 <- function(z, W.z = W(z, branch = -1)) {
 #' @rdname deprecated-functions
 #' @export
 p_1 <- function(...) {
-  warning("DEPRECATED: Please use p_1m() instead of p_m1().")
+  stop("DEPRECATED: Please use p_m1() instead of p_1().")
   p_m1(...)
 }
 
 #' @rdname deprecated-functions
 #' @export
 params2theta <- function(...) {
-  warning("DEPRECATED: Please use unflatten_theta() instead of unflatten_theta().")
+  stop("DEPRECATED: Please use unflatten_theta() instead of params2theta().")
   unflatten_theta(...)
 }
 
 #' @rdname deprecated-functions
 #' @export
 skewness_test <- function(...) {
-  warning("DEPRECATED: Please use test_symmetry() instead of skewness_test().")
+  stop("DEPRECATED: Please use test_symmetry() instead of skewness_test().")
   test_symmetry(...)
 }
 
@@ -66,14 +66,14 @@ skewness_test <- function(...) {
 #' @export
 starting_theta <- function(...) {
   
-  warning("DEPRECATED: Please use get_initial_theta() instead of starting_theta().")
+  stop("DEPRECATED: Please use get_initial_theta() instead of starting_theta().")
   get_initial_theta(...)
 }
 
 #' @rdname deprecated-functions
 #' @export
 support <- function(...) {
-  warnings("DEPRECATED: Please use 'get_support()' instead.")
+  warnings("DEPRECATED: Please use get_support() instead of support().")
   get_support(...)
 }
 
@@ -82,7 +82,7 @@ support <- function(...) {
 #' @export
 normfit <- function(...) {
   
-  warning("DEPRECATED: Please use test_normality() (or 'test_norm()') ",
+  stop("DEPRECATED: Please use test_normality() (or 'test_norm()') ",
           "instead of normfit().")
   test_normality(...)
 }
@@ -91,21 +91,21 @@ normfit <- function(...) {
 #' @rdname deprecated-functions
 #' @export
 theta2params <- function(...) {
-  warning("DEPRECATED: use flatten_theta instead of theta2params.")
+  stop("DEPRECATED: use flatten_theta() instead of theta2params().")
   flatten_theta(...)
 }
 
 #' @rdname deprecated-functions
 #' @export
 vec.norm <- function(...) {
-  warning("DEPRECATED: Please use lp_norm() instead of vec.norm().")
+  stop("DEPRECATED: Please use lp_norm() instead of vec.norm().")
   return(lp_norm(...))
 }
 
 #' @rdname deprecated-functions
 #' @export
 W_1 <- function(z) {
-  # warning("DEPRECATED: Please use W(z, branch = -1) instead of W_1(z).")
+  stop("DEPRECATED: Please use W(z, branch = -1) instead of W_1(z).")
   return(W(z, branch = -1))
 }
 
@@ -113,7 +113,7 @@ W_1 <- function(z) {
 #' @param gamma see \code{\link{W_gamma}}.
 #' @export
 W_gamma_1 <- function(z, gamma) {
-  warning("DEPRECATED: Please use W_gamma(..., branch = -1) instead of W_gamma_1(...).")
+  stop("DEPRECATED: Please use W_gamma(..., branch = -1) instead of W_gamma_1(...).")
   W_gamma(z, gamma, branch = -1)
 } 
 
@@ -121,6 +121,6 @@ W_gamma_1 <- function(z, gamma) {
 #' @rdname deprecated-functions
 #' @export
 H <- function(...) {
-  warning("DEPRECATED: Please use xexp(...) instead of H(...).")
+  stop("DEPRECATED: Please use xexp(...) instead of H(...).")
   return(xexp(...))
 }
